ProSHADE: Member List

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

ProSHADE_internal_spheres::ProSHADE_sphere Member List

This is the complete list of members for ProSHADE_internal_spheres::ProSHADE_sphere, including all inherited members.

allocateRotatedMap(void) | ProSHADE_internal_spheres::ProSHADE_sphere |
getInterpolationXYZ(proshade_double *x, proshade_double *y, proshade_double *z, proshade_double thetaIt, std::vector< proshade_double > *lonCO, proshade_unsign phiIt, std::vector< proshade_double > *latCO) | ProSHADE_internal_spheres::ProSHADE_sphere | protected
getLattitudeCutoffs(std::vector< proshade_double > *latCO) | ProSHADE_internal_spheres::ProSHADE_sphere | protected
getLocalAngRes(void) | ProSHADE_internal_spheres::ProSHADE_sphere |
getLocalBandwidth(void) | ProSHADE_internal_spheres::ProSHADE_sphere |
getLongitudeCutoffs(std::vector< proshade_double > *lonCO) | ProSHADE_internal_spheres::ProSHADE_sphere | protected
getMappedData(void) | ProSHADE_internal_spheres::ProSHADE_sphere |
getMapPoint(proshade_double *map, proshade_unsign xDimMax, proshade_unsign yDimMax, proshade_unsign zDimMax, proshade_signed xPos, proshade_signed yPos, proshade_signed zPos, std::vector< proshade_double > *interpVec) | ProSHADE_internal_spheres::ProSHADE_sphere | protected
getMaxCircumference(proshade_unsign xDimMax, proshade_unsign yDimMax, proshade_unsign zDimMax, proshade_double maxRange, proshade_single xSize, proshade_single ySize, proshade_single zSize) | ProSHADE_internal_spheres::ProSHADE_sphere | protected
getRotatedMappedData(proshade_unsign pos) | ProSHADE_internal_spheres::ProSHADE_sphere |
getShellRadius(void) | ProSHADE_internal_spheres::ProSHADE_sphere |
getXYZTopBottoms(proshade_unsign xDimMax, proshade_unsign yDimMax, proshade_unsign zDimMax, proshade_double x, proshade_double y, proshade_double z, proshade_signed *xBottom, proshade_signed *yBottom, proshade_signed *zBottom, proshade_signed *xTop, proshade_signed *yTop, proshade_signed *zTop) | ProSHADE_internal_spheres::ProSHADE_sphere | protected
interpolateAlongFirst(std::vector< proshade_double > c000, std::vector< proshade_double > c001, std::vector< proshade_double > c010, std::vector< proshade_double > c011, std::vector< proshade_double > c100, std::vector< proshade_double > c101, std::vector< proshade_double > c110, std::vector< proshade_double > c111, std::vector< proshade_double > *c00, std::vector< proshade_double > *c01, std::vector< proshade_double > *c10, std::vector< proshade_double > *c11, proshade_double xd) | ProSHADE_internal_spheres::ProSHADE_sphere | protected
interpolateAlongSecond(std::vector< proshade_double > c00, std::vector< proshade_double > c01, std::vector< proshade_double > c10, std::vector< proshade_double > c11, std::vector< proshade_double > *c0, std::vector< proshade_double > *c1, proshade_double yd) | ProSHADE_internal_spheres::ProSHADE_sphere | protected
mapData(proshade_double *map, proshade_unsign xDimMax, proshade_unsign yDimMax, proshade_unsign zDimMax) | ProSHADE_internal_spheres::ProSHADE_sphere | protected
ProSHADE_sphere(proshade_unsign xDimMax, proshade_unsign yDimMax, proshade_unsign zDimMax, proshade_single xSize, proshade_single ySize, proshade_single zSize, proshade_unsign shOrder, std::vector< proshade_single > *spherePos, bool progressiveMapping, proshade_unsign band, proshade_double *map, proshade_unsign *maxShellBand) | ProSHADE_internal_spheres::ProSHADE_sphere |
setRotatedMappedData(proshade_unsign pos, proshade_double value) | ProSHADE_internal_spheres::ProSHADE_sphere |
~ProSHADE_sphere(void) | ProSHADE_internal_spheres::ProSHADE_sphere |